==> artemis_ui_kit-0.0.2.tar.gz: lib/src/ArtemisButtonPanel.dart <==
import 'package:flutter/material.dart';

import 'Consts.dart';
import 'artemis_icons_icons.dart';

class ArtemisButtonPanel extends StatelessWidget {
  final Widget? centerWidget;
  final Widget? leftWidget;
  final Widget? rightWidget;
  final void Function()? centerAction;
  final void Function()? rightAction;
  final void Function()? leftAction;
  final double size;
  final double radius;
  final Color backgroundColor;
  final Color linesColor;

  const ArtemisButtonPanel(
      {Key? key,
        this.centerWidget,
        this.backgroundColor = ArtemisColors.white2,
        this.linesColor = ArtemisColors.veryLightPink,
        this.size=40,
        this.radius=5,
        this.leftWidget,
        this.rightWidget,
        this.centerAction,
        this.rightAction,
        this.leftAction
      });

  @override
  Widget build(BuildContext context) {
    ThemeData theme = Theme.of(context);
    return Container(
      child: Row(
        children: [
          SizedBox(
              width: size,
              height: size,
              child: OutlinedButton(
                  style: OutlinedButton.styleFrom(
                      padding: EdgeInsets.zero,
                      side: BorderSide(width: 1, color: linesColor),
                      backgroundColor: backgroundColor,
                      shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.only(
                            topLeft: Radius.circular(radius),
                            bottomLeft: Radius.circular(radius),
                          ))),
                  onPressed:leftAction,
                  child:leftWidget?? Icon(ArtemisIcons.left___arrow, size: 14, color: ArtemisColors.brownGrey))),
          Expanded(
            child: SizedBox(
              height: size,
              child: OutlinedButton(
                  style: OutlinedButton.styleFrom(
                      side: BorderSide(width: 1, color: linesColor),
                      backgroundColor: backgroundColor,
                      shape: RoundedRectangleBorder(borderRadius: BorderRadius.zero)),
                  onPressed: centerAction,
                  child:centerWidget?? Text(
                    "-",
                    style: theme.textTheme.headline5,
                  )),
            ),
          ),
          SizedBox(
              width: size,
              height: size,
              child: OutlinedButton(
                  style: OutlinedButton.styleFrom(
                      padding: EdgeInsets.zero,
                      side: BorderSide(width: 1, color: linesColor),
                      backgroundColor:backgroundColor,
                      shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.only(
                            bottomRight: Radius.circular(radius),
                            topRight: Radius.circular(radius),
                          ))),
                  onPressed: rightAction,
                  child:rightWidget?? Icon(
                    ArtemisIcons.right_arrow,
                    size: 14,
                    color: ArtemisColors.brownGrey,
                  ))),
        ],
      ),
    );
  }
}

==> artemis_ui_kit-0.0.3.tar.gz: lib/src/ArtemisButtonPanel.dart <==
import 'package:flutter/material.dart';

import 'Consts.dart';
import 'artemis_icons_icons.dart';

class ArtemisButtonPanel extends StatelessWidget {
  final Widget? centerWidget;
  final Widget? leftWidget;
  final Widget? rightWidget;
  final void Function()? centerAction;
  final void Function()? rightAction;
  final void Function()? leftAction;
  final double size;
  final double radius;
  final Color backgroundColor;
  final Color linesColor;

  const ArtemisButtonPanel(
      {Key? key,
      this.centerWidget,
      this.backgroundColor = ArtemisColors.white2,
      this.linesColor = ArtemisColors.veryLightPink,
      this.size = 40,
      this.radius = 5,
      this.leftWidget,
      this.rightWidget,
      this.centerAction,
      this.rightAction,
      this.leftAction});

  @override
  Widget build(BuildContext context) {
    ThemeData theme = Theme.of(context);
    return Container(
      child: Row(
        children: [
          SizedBox(
              width: size,
              height: size,
              child: OutlinedButton(
                  style: OutlinedButton.styleFrom(
                      padding: EdgeInsets.zero,
                      side: BorderSide(width: 1, color: linesColor),
                      backgroundColor: backgroundColor,
                      shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.only(
                        topLeft: Radius.circular(radius),
                        bottomLeft: Radius.circular(radius),
                      ))),
                  onPressed: leftAction,
                  child: leftWidget ??
                      Icon(ArtemisIcons.left___arrow,
                          size: 14, color: ArtemisColors.brownGrey))),
          Expanded(
            child: SizedBox(
              height: size,
              child: OutlinedButton(
                  style: OutlinedButton.styleFrom(
                      side: BorderSide(width: 1, color: linesColor),
                      backgroundColor: backgroundColor,
                      shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.zero)),
                  onPressed: centerAction,
                  child: centerWidget ??
                      Text(
                        "-",
                        style: theme.textTheme.headline5,
                      )),
            ),
          ),
          SizedBox(
              width: size,
              height: size,
              child: OutlinedButton(
                  style: OutlinedButton.styleFrom(
                      padding: EdgeInsets.zero,
                      side: BorderSide(width: 1, color: linesColor),
                      backgroundColor: backgroundColor,
                      shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.only(
                        bottomRight: Radius.circular(radius),
                        topRight: Radius.circular(radius),
                      ))),
                  onPressed: rightAction,
                  child: rightWidget ??
                      Icon(
                        ArtemisIcons.right_arrow,
                        size: 14,
                        color: ArtemisColors.brownGrey,
                      ))),
        ],
      ),
    );
  }
}
